from typing import Optional

from abqpy.decorators import abaqus_class_doc

from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class SurfaceHeatFluxState(LoadState):
    """The SurfaceHeatFluxState object stores the propagating data for a surface
    SurfaceHeatFlux object in a step. One instance of this object is created internally by
    the SurfaceHeatFlux object for each step. The instance is also deleted internally by the
    SurfaceHeatFlux object.
    The SurfaceHeatFluxState object has no constructor or methods.
    The SurfaceHeatFluxState object is derived from the LoadState object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - DSFLUX
    """

    #: A Float specifying the surface heat flux magnitude.
    magnitude: Optional[float] = None

    #: A SymbolicConstant specifying the propagation state of the surface heat flux magnitude.
    #: Possible values are UNSET, SET, UNCHANGED, and MODIFIED.
    magnitudeState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: Optional[SymbolicConstant] = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



from typing import Sequence

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .ConstrainedSketchGeometry import ConstrainedSketchGeometry


@abaqus_class_doc
class Arc3Points(ConstrainedSketchGeometry):
    @abaqus_method_doc
    def __init__(self, point1: Sequence[float], point2: Sequence[float], point3: Sequence[float]):
        """This method constructs an arc using a two endpoints and an intermediate third point on
        the arc.

        .. note::
            This function can be accessed by::

                mdb.models[name].sketches[name].Arc3Points

        Parameters
        ----------
        point1
            A pair of Floats specifying the first endpoint of the arc.
        point2
            A pair of Floats specifying the second endpoint of the arc.
        point3
            A pair of Floats specifying the third point on the arc.

        Returns
        -------
        ConstrainedSketchGeometry
            A ConstrainedSketchGeometry object (None if the arc cannot be created).

        """
        ...



from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class InteractionProperty:
    """The InteractionProperty object is the abstract base type for other InteractionProperty
    objects. The InteractionProperty object has no explicit constructor, members, or
    methods.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactionProperties[name]
    """

    ...
